==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaRealizacja.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.StatusRealizacjiDiagnozy;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DiagnozaRealizacja extends GenericDPSObject {
    /**
     * DIAGNOZA_REALIZACJA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DIAGNOZA_REALIZACJA.DIAGNOZA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long diagnozaId;

    /**
     * DIAGNOZA_REALIZACJA.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaDpsId;

    /**
     * DIAGNOZA_REALIZACJA.PRACOWNIK_WYKONAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikWykonalId;

    /**
     * DIAGNOZA_REALIZACJA.CZY_WSTEPNA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean czyWstepna;

    /**
     * DIAGNOZA_REALIZACJA.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * DIAGNOZA_REALIZACJA.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusRealizacjiDiagnozy status;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_REALIZACJA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DIAGNOZA_REALIZACJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.DIAGNOZA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDiagnozaId() {
        return diagnozaId;
    }

    /**
     * DIAGNOZA_REALIZACJA.DIAGNOZA_ID
     *
     * @param diagnozaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDiagnozaId(Long diagnozaId) {
        this.diagnozaId = diagnozaId;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * DIAGNOZA_REALIZACJA.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.PRACOWNIK_WYKONAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikWykonalId() {
        return pracownikWykonalId;
    }

    /**
     * DIAGNOZA_REALIZACJA.PRACOWNIK_WYKONAL_ID
     *
     * @param pracownikWykonalId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikWykonalId(Long pracownikWykonalId) {
        this.pracownikWykonalId = pracownikWykonalId;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.CZY_WSTEPNA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getCzyWstepna() {
        return czyWstepna;
    }

    /**
     * DIAGNOZA_REALIZACJA.CZY_WSTEPNA
     *
     * @param czyWstepna
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setCzyWstepna(Boolean czyWstepna) {
        this.czyWstepna = czyWstepna;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * DIAGNOZA_REALIZACJA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusRealizacjiDiagnozy getStatus() {
        return status;
    }

    /**
     * DIAGNOZA_REALIZACJA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusRealizacjiDiagnozy status) {
        this.status = status;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaRealizacja other = (DiagnozaRealizacja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDiagnozaId() == null ? other.getDiagnozaId() == null : this.getDiagnozaId().equals(other.getDiagnozaId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getPracownikWykonalId() == null ? other.getPracownikWykonalId() == null : this.getPracownikWykonalId().equals(other.getPracownikWykonalId()))
            && (this.getCzyWstepna() == null ? other.getCzyWstepna() == null : this.getCzyWstepna().equals(other.getCzyWstepna()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDiagnozaId() == null) ? 0 : getDiagnozaId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getPracownikWykonalId() == null) ? 0 : getPracownikWykonalId().hashCode());
        result = prime * result + ((getCzyWstepna() == null) ? 0 : getCzyWstepna().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", diagnozaId=").append(diagnozaId);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", pracownikWykonalId=").append(pracownikWykonalId);
        sb.append(", czyWstepna=").append(czyWstepna);
        sb.append(", data=").append(data);
        sb.append(", status=").append(status);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaRealizacja.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.StatusRealizacjiDiagnozy;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DiagnozaRealizacja extends GenericDPSObject {
    /**
     * DIAGNOZA_REALIZACJA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DIAGNOZA_REALIZACJA.DIAGNOZA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long diagnozaId;

    /**
     * DIAGNOZA_REALIZACJA.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaDpsId;

    /**
     * DIAGNOZA_REALIZACJA.PRACOWNIK_WYKONAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikWykonalId;

    /**
     * DIAGNOZA_REALIZACJA.CZY_WSTEPNA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean czyWstepna;

    /**
     * DIAGNOZA_REALIZACJA.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * DIAGNOZA_REALIZACJA.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusRealizacjiDiagnozy status;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_REALIZACJA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DIAGNOZA_REALIZACJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.DIAGNOZA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDiagnozaId() {
        return diagnozaId;
    }

    /**
     * DIAGNOZA_REALIZACJA.DIAGNOZA_ID
     *
     * @param diagnozaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDiagnozaId(Long diagnozaId) {
        this.diagnozaId = diagnozaId;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * DIAGNOZA_REALIZACJA.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.PRACOWNIK_WYKONAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikWykonalId() {
        return pracownikWykonalId;
    }

    /**
     * DIAGNOZA_REALIZACJA.PRACOWNIK_WYKONAL_ID
     *
     * @param pracownikWykonalId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikWykonalId(Long pracownikWykonalId) {
        this.pracownikWykonalId = pracownikWykonalId;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.CZY_WSTEPNA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getCzyWstepna() {
        return czyWstepna;
    }

    /**
     * DIAGNOZA_REALIZACJA.CZY_WSTEPNA
     *
     * @param czyWstepna
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setCzyWstepna(Boolean czyWstepna) {
        this.czyWstepna = czyWstepna;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * DIAGNOZA_REALIZACJA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return DIAGNOZA_REALIZACJA.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusRealizacjiDiagnozy getStatus() {
        return status;
    }

    /**
     * DIAGNOZA_REALIZACJA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusRealizacjiDiagnozy status) {
        this.status = status;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaRealizacja other = (DiagnozaRealizacja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDiagnozaId() == null ? other.getDiagnozaId() == null : this.getDiagnozaId().equals(other.getDiagnozaId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getPracownikWykonalId() == null ? other.getPracownikWykonalId() == null : this.getPracownikWykonalId().equals(other.getPracownikWykonalId()))
            && (this.getCzyWstepna() == null ? other.getCzyWstepna() == null : this.getCzyWstepna().equals(other.getCzyWstepna()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDiagnozaId() == null) ? 0 : getDiagnozaId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getPracownikWykonalId() == null) ? 0 : getPracownikWykonalId().hashCode());
        result = prime * result + ((getCzyWstepna() == null) ? 0 : getCzyWstepna().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", diagnozaId=").append(diagnozaId);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", pracownikWykonalId=").append(pracownikWykonalId);
        sb.append(", czyWstepna=").append(czyWstepna);
        sb.append(", data=").append(data);
        sb.append(", status=").append(status);
        sb.append("]");
        return sb.toString();
    }
}
